@@ -32,19 +32,24 @@ get_bls_state <- function(date_mth=NULL, seasonality = TRUE){
     
     # If no date_mth is specified, find the latest month and return.
     # Not happy with this method. Would rather find max(month) in data. But data format is a bit crazy.
-    if (isTRUE(any(grepl(format(zoo::as.yearmon(Sys.Date()-30), "%B %Y"), dat)))){
-        date_mth <- format(zoo::as.yearmon(Sys.Date()-30), "%B %Y")
-    }else{
-        if (isTRUE(any(grepl(format(zoo::as.yearmon(Sys.Date()-60), "%B %Y"), dat)))){
-            date_mth <- format(zoo::as.yearmon(Sys.Date()-60), "%B %Y")
-        }else{date_mth <- format(zoo::as.yearmon(Sys.Date()-90), "%B %Y")}
+    if (is.null(date_mth)){
+        if (isTRUE(any(grepl(format(zoo::as.yearmon(Sys.Date()-30), "%B %Y"), dat)))){
+            date_mth <- format(zoo::as.yearmon(Sys.Date()-30), "%B %Y")
+        }else{
+            if (isTRUE(any(grepl(format(zoo::as.yearmon(Sys.Date()-60), "%B %Y"), dat)))){
+                date_mth <- format(zoo::as.yearmon(Sys.Date()-60), "%B %Y")
+            }else{date_mth <- format(zoo::as.yearmon(Sys.Date()-90), "%B %Y")}
+        }
     }
     
     # Make an empty list for data frames and iterate in big nasty for loop.
     datalist <- list()
     for (i in date_mth) {
-        #datebegin <- unique(grep(paste(i, collapse = "|"),dat)) + 3
-        datebegin <- grep(i, dat) +3
+        if(i=="January 1976"){
+            datebegin=4
+        }else{
+            datebegin <- grep(i, dat) +3
+        }
         dateend = datebegin+52
         vals <- gsub("^\ +|\ +$", "", dat[datebegin:dateend])
         vals <- unique(grep(paste(state.name, sep="", collapse="|"), 
@@ -54,9 +59,15 @@ get_bls_state <- function(date_mth=NULL, seasonality = TRUE){
         nycrow <- grep(c("New York city"), vals)
         larow <- grep(c("Los Angeles County"), vals)
         dcrow <- grep(c("District of Columbia"), vals)
-        vals <- vals[-c(nycrow)]
-        vals <- vals[-c(larow)]
-        vals <- vals[-c(dcrow)]
+        if(length(nycrow)>0){
+            vals <- vals[-c(nycrow)]
+        }
+        if(length(larow)>0){
+            vals <- vals[-c(larow)]
+        }
+        if(length(dcrow)>0){
+            vals <- vals[-c(dcrow)]
+        }
         
         # Split out state names, so read.table doesn't get confused.
         state_vals <- gsub("^.* \\.+", "", vals)
@@ -81,6 +92,6 @@ get_bls_state <- function(date_mth=NULL, seasonality = TRUE){
     state_fips<-blscrapeR::state_fips
     df <- merge(df, state_fips, by = "state")
     df <- df[order(df$month, df$state),]
-                                                                                                                        
-return(df)
-}
+    
+    return(df)
+}
\ No newline at end of file
